@@ -17,7 +17,7 @@ function(DATA,make_data_nominal=TRUE,DESIGN=NULL,make_design_nominal=TRUE,masses
 	##if the data table is nominal, the col & row Sums should be identical and have 1 unique element.
 	numUniqueRows <- length(unique(round(rowSums(nominalData))))
 	if( weCanCorrect && (numUniqueRows==1) ){
-		res <- mca.eigen.fix(nominalData,res, make_data_nominal=FALSE,correction=correction)
+		res <- mca.eigen.fix(nominalData,res, make_data_nominal=FALSE,correction=correction,symmetric=symmetric)
 	}else{
 		#basically nothing
 		print('No corrections available.')
